/*
 * MmsQuestion.java -  Dialog class to handle button choice questions
 *
 *      Copyright (C) - 2006 Michael Latham
 *      This software may be freely distributed and modified under the GNU General Public License, Version 2 or later,
 *      as published by the Free Software Foundation.
 *
 *      This software is NOT guaranteed or warrantied.  USE AT YOUR OWN RISK.  The author and/or authors cannot be held
 *      responsible for any misuse or damage.
 *
 *      NOTE: Please add revisions as file is changed!
 *
 *      REV         DATE                        DESCRIPTION
 *      -----       ----------          --------------------------------------------------
 *      00.00       2006-04-09          Initial Implementation
 */

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.plaf.basic.BasicOptionPaneUI.*;

/**
 * Dialog to handle questions or errors.
 * @author  Michael Latham
 */
public class MmsQuestion extends JDialog implements MouseListener{

    Container   m_cp        = null;
    JPanel      m_pQuestion = null;
    JPanel      m_pButtons  = null;
    String      m_answer    = "";
    
    /**
     * Default constructor
     */
    public MmsQuestion () {
        super();
    }
     
    /**
     * Preferred constructor
     * @param frame Parent frame
     * @param title Title for new dialog
     * @param modal True if dialog should be modal
     */
    public MmsQuestion ( JFrame frame, String title, boolean modal ) {
        super( frame, title, modal );
    }
     
    /**
     * Alternate preferred constructor
     * @param dlg   Parent dialog
     * @param title Title for new dialog
     */
    public MmsQuestion ( JDialog dlg, String title ) {
        super( dlg, title, true );
        initialize();
    }
     
    /**
     * Call this method after constructing to prepare for dialog
     */
    public void initialize() {
        m_cp = getContentPane();
        m_cp.setLayout( new BorderLayout(10,10) );
        m_pButtons = new JPanel();
        m_pQuestion = new JPanel();

        Dimension paneSize = new Dimension( 300, 125 );
        setMinimumSize( paneSize );
        setPreferredSize( paneSize );
        setSize( paneSize );
        Window win = getOwner();
        if (win != null) {
            Point loc = win.getLocation();
            setLocation( loc.x + 10, loc.y + 10 );
        }
        else {
            setLocation( 200, 100 );
        }

        m_cp.add( m_pQuestion, BorderLayout.NORTH );
        m_cp.add( m_pButtons, BorderLayout.CENTER );
        m_cp.add( Box.createRigidArea(new Dimension( 0,10 )), BorderLayout.SOUTH );
    }
    
    /**
     * Adds a new button and its corresponding answer to the dialog
     * @param newButton Fully initialized button to add to dialog.  The button's text will be set in m_answer
     */
    public void addButton( JButton newButton ) {
        if (newButton == null)
            return;

        newButton.addMouseListener(this);
        m_pButtons.add( newButton );
        repaint();
    }
    
    /**
     * Adds a new button and its corresponding answer to the dialog
     * @param newButtonStr  String for button's text.  The button's text will be set in m_answer
     */
    public void addButton( String newButtonStr ) {
        if (newButtonStr == null)
            return;
        
        JButton newButton = new JButton( newButtonStr );
        
        newButton.addMouseListener(this);
        m_pButtons.add( newButton );
        repaint();
    }

    /**
     * Adds the question (or statement) to the dialog
     * @param question  Text to display
     */
    public void addQuestion( String question ) {
        if (question == null)
            return;
        
        m_pQuestion.add( new JLabel(question) );
        repaint();
    }
    
    /**
     * Returns the answer or result
     * @return Text set by any button pushed
     */
    public String getAnswer() {
        return m_answer;
    }
    
    /** 
     * Mouse click event handler
     * @param me    Event generated from mouse button click
     */
    public void mouseClicked( MouseEvent me ) {
        JButton bClicked = (JButton) me.getSource();
        
        if (bClicked == null)
            return;
        
        m_answer = bClicked.getText();
        setVisible(false);
    }

    /** mouseEntered - N/A -    Invoked when the mouse enters a component. */
    public void mouseEntered( MouseEvent me ) {
    }

    /** mouseEntered - N/A -    Invoked when the mouse exits a component. */
    public void mouseExited( MouseEvent me )  {
    }
  
    /** mousePressed - N/A - Invoked when a mouse button has been pressed on a component. */
    public void mousePressed( MouseEvent me ) {
    }
  
    /** mouseReleased - N/A - Invoked when a mouse button has been released on a component. */
    public void mouseReleased( MouseEvent me ) {
    }
}
